jactorch.optim.weight\_decay
============================

.. automodule:: jactorch.optim.weight_decay

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      AdamW
   
   

   
   
   

   
   
   








.. rubric:: Class AdamW
.. autoclass:: AdamW
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







